@@ -71,7 +71,6 @@
 				    'ept-basic-face)
 				(selected-frame)))
 	  3))))
-   
 
 (defun ept-default-font-width ()
   (aref (font-info (face-font 'ept-basic-face) (selected-frame)) 2))
@@ -130,7 +129,8 @@
 			      (max 0 (- (window-width)
 					(/ (ept-string-pixel-width
 					    string)
-					   (ept-default-font-width)))))))))
+					   (ept-default-font-width))
+					1)))))))
 
 (defun ept-string-pixel-width-2 (string)
   (let ((total 0)
