@@ -43,11 +43,11 @@
   "Elpoint editor mode derived from emacs-lisp mode."
   (run-hooks 'ept-mode-hook))
 
-(define-key ept-mode-map "\C-c\C-e" 'ept-exec-buffer)
+(define-key ept-mode-map "\C-c\C-e" 'ept-play-buffer)
 (define-key ept-mode-map "\C-c\C-d" 'ept-dump-buffer)
 (define-key ept-mode-map "\C-c\C-n" 'ept-number)
 
-(defun ept-number ()
+(defun ept-ept-number ()
   (interactive)
   (let ((pages 0)
 	(pos (point)))
@@ -59,7 +59,7 @@
       (message "Page %d" (setq pages (max 0 (- pages 1)))))
     pages))
 
-(defsubst ept-exec-internal (start-page &optional dump)
+(defun ept-ept-play-buffer (start-page &optional dump)
   (let ((source (current-buffer))
 	work presentation)
     (with-temp-buffer
@@ -74,33 +74,6 @@
       (setq presentation (read (current-buffer))))
     (ept-play presentation start-page dump)))
 
-(defun ept-exec-file (&optional file)
-  (interactive "fFile: ")
-  (find-file file)
-  (let ((buffer (current-buffer)))
-    (unwind-protect
-	(ept-exec-buffer)
-      (kill-buffer buffer))))
-
-(defun ept-dump-file (&optional file)
-  (interactive "fFile: ")
-  (find-file file)
-  (let ((buffer (current-buffer)))
-    (unwind-protect
-	(ept-dump-buffer)
-      (kill-buffer buffer))))
-
-(defun ept-exec-buffer (&optional from-current)
-  "Play current buffer content as an Elpoint presentation.
-If optional FROM-CURRENT is non-nil, start from the page under the cursor."
-  (interactive "P")
-  (ept-exec-internal (if from-current (ept-number) 0)))
-
-(defun ept-dump-buffer (&optional dir)
-  "Play current buffer content as an Elpoint presentation and dump it to DIR."
-  (interactive "DOutput Directory: ")
-  (ept-exec-internal 0 dir))
-
 (provide 'ept-mode)
 
 ;;; ept-mode.el ends here
