@@ -64,6 +64,8 @@
 (setq ept-play-frame-parameters
       `((tool-bar-lines . 0)
 	(menu-bar-lines . 0)
+	(left-fringe . 0)  ; For Emacs 21.3
+	(right-fringe . 0)
 	(line-space . 0)
 	(top . 0)
 	(left . 0)
@@ -83,10 +85,11 @@
        (1 font-lock-keyword-face)))))
 
 ;; autoload setup.
-(autoload 'ept-mode "ept-mode" nil t)
-(autoload 'ept-exec-file "ept-mode" nil t)
-(autoload 'ept-dump-file "ept-mode" nil t)
-(autoload 'ept-play "ept" nil)
+(autoload 'ept-play-file   "ept" nil t)
+(autoload 'ept-play-buffer "ept" nil t)
+(autoload 'ept-dump-file   "ept" nil t)
+(autoload 'ept-dump-buffer "ept" nil t)
+(autoload 'ept-mode        "ept-mode" nil t)
 
 ;; auto-mode setup.
 (setq auto-mode-alist
