@@ -32,12 +32,11 @@
 (eval-when-compile
   (require 'cl))
 (require 'ept-align)
-(require 'ept-dump)
 (require 'product)
 
 (product-provide 'ept
   (product-define "Elpoint" nil
-		  '(0 1 1)))
+		  '(0 2 0)))
 
 (defun elpoint-version ()
   "Return Elpoint version.
@@ -48,6 +47,10 @@ If it is called interactively, version string is appeared on minibuffer."
 	(message "%s" product-info)
       product-info)))
 
+(autoload 'ept-dump-page "ept-dump" nil)
+(autoload 'ept-dump-convert "ept-dump" nil)
+(autoload 'ept-make-dump-page "ept-dump" nil)
+
 (defvar ept-separator-string "-" "A charecter for separator")
 (defvar ept-item-point-strings '("*") "A list of a string for item point.")
 
@@ -114,31 +117,38 @@ If it is called interactively, version string is appeared on minibuffer."
   :group 'application)
 
 (defface ept-title-face
-  `((t (:foreground "Cyan" :font ,ept-title-face-font)))
+  `((t (:foreground "Cyan" ,@(if window-system
+				 (list :font ept-title-face-font)))))
   nil)
 
 (defface ept-body-face
-  `((t (:foreground "White" :font ,ept-body-face-font)))
+  `((t (:foreground "White" ,@(if window-system
+				  (list :font ept-body-face-font)))))
   nil)
 
 (defface ept-highlight-face
-  `((t (:foreground "Yellow" :font ,ept-highlight-face-font)))
+  `((t (:foreground "Yellow" ,@(if window-system
+				   (list :font ept-highlight-face-font)))))
   nil)
 
 (defface ept-separator-face
-  `((t (:foreground "Gray" :font ,ept-separator-face-font)))
+  `((t (:foreground "Gray" ,@(if window-system
+				 (list :font ept-separator-face-font)))))
   nil)
 
 (defface ept-item-face
-  `((t (:foreground "Yellow"  :font ,ept-item-face-font)))
+  `((t (:foreground "Yellow" ,@(if window-system
+				   (list :font ept-item-face-font)))))
   nil)
 
 (defface ept-item-point-face
-  `((t (:foreground "Orange" :font ,ept-item-point-face-font)))
+  `((t (:foreground "Orange" ,@(if window-system
+				   (list :font ept-item-point-face-font)))))
   nil)
 
 (defface ept-basic-face
-  `((t (:foreground "Gray" :font ,ept-basic-face-font)))
+  `((t (:foreground "Gray" ,@(if window-system
+				 (list :font ept-basic-face-font)))))
   nil)
 
 (defcustom ept-imagick-convert-program "convert"
@@ -202,6 +212,12 @@ If it is called interactively, version string is appeared on minibuffer."
   :group 'ept
   :type 'hook)
 
+(defcustom ept-play-vertical-centering-font-regexp
+  "iso8859\\|gb2312\\|jisx0208\\|jisx0212\\|ksc5601\\|cns11643\\|big5"
+  "A regexp for `vertical-centering-font-regexp'."
+  :group 'ept
+  :type 'regexp)
+
 (defconst ept-image-type-alist
   '(("image/jpeg" . jpeg)
     ("image/gif" . gif)
@@ -382,7 +398,7 @@ If it is called interactively, version string is appeared on minibuffer."
   (setq truncate-lines t)
   (make-local-variable 'vertical-centering-font-regexp)
   (setq vertical-centering-font-regexp
-	"iso8859\\|gb2312\\|jisx0208\\|jisx0212\\|ksc5601\\|cns11643\\|big5")
+	ept-play-vertical-centering-font-regexp)
   (setq major-mode 'ept-play-mode
 	mode-name "Elpoint-play")
   (run-hooks 'ept-play-mode-hook))
@@ -393,6 +409,50 @@ If it is called interactively, version string is appeared on minibuffer."
   (kill-buffer (current-buffer))
   (delete-frame))
 
+(defun ept-funcall (function &rest args)
+  (let* ((mname (when (string-match "-mode" (symbol-name major-mode))
+		  (substring (symbol-name major-mode) 0 (match-beginning 0))))
+	 (sym (intern (concat "ept-" mname "-"
+			      (symbol-name function)))))
+    (unless (eq major-mode 'ept-mode)
+      (require (intern (concat "ept-" mname))))
+    (if (fboundp sym)
+	(apply sym args)
+      (error "%s is not implemented" sym))))
+
+(defun ept-number ()
+  (ept-funcall 'number))
+
+(defun ept-play-buffer (&optional from-current)
+  "Play current buffer content as an Elpoint presentation.
+If optional FROM-CURRENT is non-nil, start from the page under the cursor."
+  (interactive "P")
+  (ept-funcall 'play-buffer (if from-current (ept-number) 0)))
+
+(defun ept-dump-buffer (&optional dir)
+  "Play current buffer content as an Elpoint presentation and dump it to DIR."
+  (interactive "DOutput Directory: ")
+  (ept-funcall 'play-buffer 0 dir))
+
+(defun ept-play-file (&optional file)
+  (interactive "fFile: ")
+  (find-file file)
+  (let ((buffer (current-buffer)))
+    (unwind-protect
+	(ept-play-buffer)
+      (kill-buffer buffer))))
+
+(defalias 'ept-exec-file 'ept-play-file)
+(defalias 'ept-exec-buffer 'ept-play-buffer)
+
+(defun ept-dump-file (&optional file)
+  (interactive "fFile: ")
+  (find-file file)
+  (let ((buffer (current-buffer)))
+    (unwind-protect
+	(ept-dump-buffer)
+      (kill-buffer buffer))))
+
 (defun ept-play (presentation start-page &optional dump)
   "Play the PRESANTATION from START-PAGE.
 If optional DUMP is non-nil, play as DUMP mode."
@@ -401,26 +461,30 @@ If optional DUMP is non-nil, play as DUMP mode."
   (let ((dir (when (buffer-file-name (current-buffer))
 	       (file-name-directory (buffer-file-name (current-buffer)))))
 	(buffer (get-buffer-create "*elpoint*"))
-	(frame (make-frame `((name . "elpoint")
-			     (font . ,(face-font 'ept-basic-face)))))
-	width height bgcolor)
-    (setq width (or ept-play-frame-width
-		    (- (/ (display-pixel-width)
-			  (aref (font-info (face-font 'ept-basic-face frame))
-				2))
-		       1)))
-    (setq height (or ept-play-frame-height
-		     (/ (display-pixel-height)
-			(aref (font-info (face-font 'ept-basic-face frame))
-			      3))))
+	(frame (make-frame
+		`((name . "elpoint")
+		  (width . ,(or ept-play-frame-width
+				(/ (display-pixel-width)
+				   (aref (font-info
+					  (face-font 
+					   'ept-basic-face
+					   (selected-frame)))
+					 2))))
+		  (height . ,(or ept-play-frame-height
+				 (/ (display-pixel-height)
+				    (aref (font-info
+					   (face-font
+					    'ept-basic-face
+					    (selected-frame)))
+					  3))))
+		  (font . ,(face-font 'ept-basic-face)))))
+	bgcolor)
     (let ((ept-play-frame-parameters
-	   (append (list (cons 'width width)
-			 (cons 'height height)
-			 (cons 'foreground-color
-			       ept-play-frame-foreground-color)
-			 (cons 'background-color
-			       ept-play-frame-background-color))
-		   ept-play-frame-parameters)))
+	   (append (list (cons 'foreground-color
+ 			       ept-play-frame-foreground-color)
+ 			 (cons 'background-color
+ 			       ept-play-frame-background-color))
+ 		   ept-play-frame-parameters)))
       (modify-frame-parameters frame ept-play-frame-parameters))
     (select-frame frame)
     (with-current-buffer buffer
@@ -493,8 +557,6 @@ don't dump current page."
 	(setq ept-current-position (- ept-current-position 1)))
       (eval (nth ept-current-position ept-current-presentation)))))
 
-(autoload 'ept-dump-page "ept-dump" nil)
-
 (provide 'ept)
 
 ;;; ept.el ends here
